@@ -34,6 +34,8 @@ const (
 	missingSecret        = "missing_secret"
 	missingTBRCredential = "missing_tbr_credential"
 
+	tbrInaccessibleOnBootstrapQuery = "openshift_samples_tbr_inaccessible_info"
+
 	// MetricsPort is the IP port supplied to the HTTP server used for prometheus,
 	// and matches what is specified in the corresponding Service and ServiceMonitor
 	MetricsPort = 60000
@@ -56,6 +58,10 @@ var (
 		Name: invalidConfigQuery,
 		Help: "Indicates the configuration for the samples operator has an invalid configuration setting.",
 	})
+	tbrInaccessibleOnBootStat = prometheus.NewGauge(prometheus.GaugeOpts{
+		Name: tbrInaccessibleOnBootstrapQuery,
+		Help: "Indicates that during its initial installation the samples operator could not access registry.redhat.io and it boostrapped as removed.",
+	})
 
 	sc         = samplesCollector{}
 	registered = false
@@ -143,7 +149,7 @@ func (sc *samplesCollector) Collect(ch chan<- prometheus.Metric) {
 		addCountGauge(ch, invalidSecretDesc, missingTBRCredential, float64(0))
 		return
 	}
-	secret, err := sc.secrets.Get(configv1.SamplesRegistryCredentials)
+	secret, err := sc.secrets.Get("pull-secret")
 	if err != nil {
 		logrus.Infof("metrics pull secret retrieval failed with: %s", err.Error())
 		addCountGauge(ch, invalidSecretDesc, missingTBRCredential, float64(1))
@@ -179,11 +185,11 @@ func addCountGauge(ch chan<- prometheus.Metric, desc *prometheus.Desc, name stri
 }
 
 func init() {
-	prometheus.MustRegister(degradedStat, configInvalidStat)
+	prometheus.MustRegister(degradedStat, configInvalidStat, tbrInaccessibleOnBootStat)
 }
 
 func InitializeMetricsCollector(listers *client.Listers) {
-	sc.secrets = listers.OpenShiftNamespaceSecrets
+	sc.secrets = listers.ConfigNamespaceSecrets
 	sc.config = listers.Config
 
 	if !registered {
