@@ -1,6 +1,7 @@
 package e2e
 
 import (
+	"context"
 	"fmt"
 	"io/ioutil"
 	"net"
@@ -22,13 +23,13 @@ import (
 	configv1 "github.com/openshift/api/config/v1"
 	imageapiv1 "github.com/openshift/api/image/v1"
 	operatorsv1api "github.com/openshift/api/operator/v1"
+	samplesapi "github.com/openshift/api/samples/v1"
 	templatev1 "github.com/openshift/api/template/v1"
 	configv1client "github.com/openshift/client-go/config/clientset/versioned/typed/config/v1"
 	imageset "github.com/openshift/client-go/image/clientset/versioned"
-	templateset "github.com/openshift/client-go/template/clientset/versioned"
-	samplesapi "github.com/openshift/api/samples/v1"
-	sampopclient "github.com/openshift/cluster-samples-operator/pkg/client"
 	sampleclientv1 "github.com/openshift/client-go/samples/clientset/versioned"
+	templateset "github.com/openshift/client-go/template/clientset/versioned"
+	sampopclient "github.com/openshift/cluster-samples-operator/pkg/client"
 	operator "github.com/openshift/cluster-samples-operator/pkg/operatorstatus"
 	"github.com/openshift/cluster-samples-operator/pkg/stub"
 	"github.com/openshift/cluster-samples-operator/pkg/util"
@@ -91,7 +92,7 @@ func setupClients(t *testing.T) {
 
 func dumpPod(t *testing.T) {
 	podClient := kubeClient.CoreV1().Pods(samplesapi.OperatorNamespace)
-	podList, err := podClient.List(metav1.ListOptions{})
+	podList, err := podClient.List(context.TODO(), metav1.ListOptions{})
 	if err != nil {
 		t.Fatalf("error list pods %v", err)
 	}
@@ -102,7 +103,7 @@ func dumpPod(t *testing.T) {
 			pod.Status.Phase == corev1.PodRunning {
 			for _, container := range pod.Spec.Containers {
 				req := podClient.GetLogs(pod.Name, &corev1.PodLogOptions{Container: container.Name})
-				readCloser, err := req.Stream()
+				readCloser, err := req.Stream(context.TODO())
 				if err != nil {
 					t.Fatalf("error getting pod logs for container %s: %s", container.Name, err.Error())
 				}
@@ -123,7 +124,7 @@ func verifyOperatorUp(t *testing.T) *samplesapi.Config {
 	var cfg *samplesapi.Config
 	var err error
 	err = wait.PollImmediate(1*time.Second, 10*time.Minute, func() (bool, error) {
-		cfg, err = crClient.SamplesV1().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+		cfg, err = crClient.SamplesV1().Configs().Get(context.TODO(), samplesapi.ConfigName, metav1.GetOptions{})
 		if err != nil {
 			t.Logf("%v", err)
 			return false, nil
@@ -159,7 +160,7 @@ func verifySupportedArch(t *testing.T) bool {
 
 func verifyIPv6(t *testing.T) bool {
 	err := wait.PollImmediate(1*time.Second, 1*time.Minute, func() (bool, error) {
-		networkConfig, err := configClient.Networks().Get("cluster", metav1.GetOptions{})
+		networkConfig, err := configClient.Networks().Get(context.TODO(), "cluster", metav1.GetOptions{})
 		if !stub.IsRetryableAPIError(err) && err != nil {
 			t.Logf("verifyIPv6 got unretryable error %s", err.Error())
 			return false, err
@@ -200,28 +201,9 @@ func verifyIPv6(t *testing.T) bool {
 	return false
 }
 
-func verifySecretPresent(t *testing.T) {
-	setupClients(t)
-	secClient := kubeClient.CoreV1().Secrets("openshift")
-	err := wait.PollImmediate(1*time.Second, 10*time.Minute, func() (bool, error) {
-		_, err := secClient.Get(samplesapi.SamplesRegistryCredentials, metav1.GetOptions{})
-		if err != nil {
-			if !kerrors.IsNotFound(err) {
-				t.Logf("%v", err)
-			}
-			return false, nil
-		}
-		return true, nil
-	})
-	if err != nil {
-		dumpPod(t)
-		t.Fatalf("timeout for secret getting created cfg %#v", verifyOperatorUp(t))
-	}
-}
-
 func verifyConditionsCompleteSamplesAdded(t *testing.T) error {
 	return wait.PollImmediate(1*time.Second, 10*time.Minute, func() (bool, error) {
-		cfg, err := crClient.SamplesV1().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+		cfg, err := crClient.SamplesV1().Configs().Get(context.TODO(), samplesapi.ConfigName, metav1.GetOptions{})
 		if err != nil {
 			t.Logf("%v", err)
 			return false, nil
@@ -240,7 +222,7 @@ func verifyConditionsCompleteSamplesAdded(t *testing.T) error {
 
 func verifyConditionsCompleteSamplesRemoved(t *testing.T) error {
 	return wait.PollImmediate(1*time.Second, 10*time.Minute, func() (bool, error) {
-		cfg, err := crClient.SamplesV1().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+		cfg, err := crClient.SamplesV1().Configs().Get(context.TODO(), samplesapi.ConfigName, metav1.GetOptions{})
 		if err != nil {
 			t.Logf("%v", err)
 			return false, nil
@@ -258,7 +240,7 @@ func verifyClusterOperatorConditionsComplete(t *testing.T, expectedVersion strin
 	var state *configv1.ClusterOperator
 	var err error
 	err = wait.PollImmediate(1*time.Second, 10*time.Minute, func() (bool, error) {
-		state, err = configClient.ClusterOperators().Get(operator.ClusterOperatorName, metav1.GetOptions{})
+		state, err = configClient.ClusterOperators().Get(context.TODO(), operator.ClusterOperatorName, metav1.GetOptions{})
 		if err != nil {
 			t.Logf("%v", err)
 			return false, nil
@@ -426,7 +408,7 @@ func verifyImageStreamsPresent(t *testing.T, content map[string]bool, timeToComp
 		var err error
 
 		err = wait.PollImmediate(1*time.Second, 10*time.Minute, func() (bool, error) {
-			is, err = imageClient.ImageV1().ImageStreams("openshift").Get(key, metav1.GetOptions{})
+			is, err = imageClient.ImageV1().ImageStreams("openshift").Get(context.TODO(), key, metav1.GetOptions{})
 			if err != nil {
 				t.Logf("%v", err)
 				return false, nil
@@ -459,7 +441,7 @@ func verifyImageChangesInProgress(t *testing.T) {
 	var cfg *samplesapi.Config
 	var err error
 	err = wait.PollImmediate(1*time.Second, 3*time.Minute, func() (bool, error) {
-		cfg, err = crClient.SamplesV1().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+		cfg, err = crClient.SamplesV1().Configs().Get(context.TODO(), samplesapi.ConfigName, metav1.GetOptions{})
 		if err != nil {
 			t.Logf("%v", err)
 			return false, nil
@@ -476,7 +458,7 @@ func verifyImageStreamsGone(t *testing.T) {
 	content := getSamplesNames(getContentDir(t), nil, t)
 	streams, _ := content[imagestreamsKey]
 	for key := range streams {
-		_, err := imageClient.ImageV1().ImageStreams("openshift").Get(key, metav1.GetOptions{})
+		_, err := imageClient.ImageV1().ImageStreams("openshift").Get(context.TODO(), key, metav1.GetOptions{})
 		if err == nil {
 			dumpPod(t)
 			cfg := verifyOperatorUp(t)
@@ -492,7 +474,7 @@ func verifyTemplatesPresent(t *testing.T, content map[string]bool, timeToCompare
 		var err error
 
 		err = wait.PollImmediate(1*time.Second, 10*time.Minute, func() (bool, error) {
-			template, err = templateClient.TemplateV1().Templates("openshift").Get(key, metav1.GetOptions{})
+			template, err = templateClient.TemplateV1().Templates("openshift").Get(context.TODO(), key, metav1.GetOptions{})
 			if err != nil {
 				t.Logf("%v", err)
 				return false, nil
@@ -526,7 +508,7 @@ func verifyTemplatesGone(t *testing.T) {
 	content := getSamplesNames(getContentDir(t), nil, t)
 	templates, _ := content[templatesKey]
 	for key := range templates {
-		_, err := templateClient.TemplateV1().Templates("openshift").Get(key, metav1.GetOptions{})
+		_, err := templateClient.TemplateV1().Templates("openshift").Get(context.TODO(), key, metav1.GetOptions{})
 		if err == nil {
 			dumpPod(t)
 			cfg := verifyOperatorUp(t)
@@ -553,7 +535,7 @@ func validateContent(t *testing.T, timeToCompare *kapis.Time) {
 
 func verifyConfigurationValid(t *testing.T, status corev1.ConditionStatus) {
 	err := wait.PollImmediate(1*time.Second, 3*time.Minute, func() (bool, error) {
-		cfg, e := crClient.SamplesV1().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+		cfg, e := crClient.SamplesV1().Configs().Get(context.TODO(), samplesapi.ConfigName, metav1.GetOptions{})
 		if e != nil {
 			t.Logf("%v", e)
 			return false, nil
@@ -571,7 +553,7 @@ func verifyConfigurationValid(t *testing.T, status corev1.ConditionStatus) {
 }
 
 func verifyDeletedImageStreamRecreated(t *testing.T) {
-	err := imageClient.ImageV1().ImageStreams("openshift").Delete("jenkins", &metav1.DeleteOptions{})
+	err := imageClient.ImageV1().ImageStreams("openshift").Delete(context.TODO(), "jenkins", metav1.DeleteOptions{})
 	if err != nil {
 		dumpPod(t)
 		cfg := verifyOperatorUp(t)
@@ -582,7 +564,7 @@ func verifyDeletedImageStreamRecreated(t *testing.T) {
 	// then make sure the image changes are complete before attempting to fetch deleted IS
 	verifyConditionsCompleteSamplesAdded(t)
 	err = wait.PollImmediate(1*time.Second, 30*time.Second, func() (bool, error) {
-		_, err := imageClient.ImageV1().ImageStreams("openshift").Get("jenkins", metav1.GetOptions{})
+		_, err := imageClient.ImageV1().ImageStreams("openshift").Get(context.TODO(), "jenkins", metav1.GetOptions{})
 		if err == nil {
 			return true, nil
 		}
@@ -601,7 +583,7 @@ func verifyDeletedImageStreamRecreated(t *testing.T) {
 
 func verifySkippedStreamManagedLabel(t *testing.T, value string) {
 	err := wait.PollImmediate(1*time.Second, 10*time.Second, func() (bool, error) {
-		stream, err := imageClient.ImageV1().ImageStreams("openshift").Get("jenkins", metav1.GetOptions{})
+		stream, err := imageClient.ImageV1().ImageStreams("openshift").Get(context.TODO(), "jenkins", metav1.GetOptions{})
 		if err != nil {
 			t.Logf("%v", err)
 			return true, nil
@@ -624,7 +606,7 @@ func verifySkippedStreamManagedLabel(t *testing.T, value string) {
 
 func verifySkippedTemplateManagedLabel(t *testing.T, value string) {
 	err := wait.PollImmediate(1*time.Second, 10*time.Second, func() (bool, error) {
-		stream, err := templateClient.TemplateV1().Templates("openshift").Get("jenkins-ephemeral", metav1.GetOptions{})
+		stream, err := templateClient.TemplateV1().Templates("openshift").Get(context.TODO(), "jenkins-ephemeral", metav1.GetOptions{})
 		if err != nil {
 			t.Logf("%v", err)
 			return true, nil
@@ -653,7 +635,7 @@ func verifyDeletedImageStreamNotRecreated(t *testing.T) {
 		return
 	}
 
-	err := imageClient.ImageV1().ImageStreams("openshift").Delete("jenkins", &metav1.DeleteOptions{})
+	err := imageClient.ImageV1().ImageStreams("openshift").Delete(context.TODO(), "jenkins", metav1.DeleteOptions{})
 	if err != nil {
 		dumpPod(t)
 		cfg := verifyOperatorUp(t)
@@ -662,7 +644,7 @@ func verifyDeletedImageStreamNotRecreated(t *testing.T) {
 	// make sure jenkins imagestream does not appear while unmanaged
 	// first, wait sufficiently to make sure delete has gone though
 	err = wait.PollImmediate(1*time.Second, 10*time.Second, func() (bool, error) {
-		_, err := imageClient.ImageV1().ImageStreams("openshift").Get("jenkins", metav1.GetOptions{})
+		_, err := imageClient.ImageV1().ImageStreams("openshift").Get(context.TODO(), "jenkins", metav1.GetOptions{})
 		if kerrors.IsNotFound(err) {
 			return true, nil
 		}
@@ -675,7 +657,7 @@ func verifyDeletedImageStreamNotRecreated(t *testing.T) {
 	}
 	// now make sure it has not been recreated
 	time.Sleep(30 * time.Second)
-	_, err = imageClient.ImageV1().ImageStreams("openshift").Get("jenkins", metav1.GetOptions{})
+	_, err = imageClient.ImageV1().ImageStreams("openshift").Get(context.TODO(), "jenkins", metav1.GetOptions{})
 	if err == nil {
 		dumpPod(t)
 		t.Fatalf("imagestream recreated, cfg: %#v", verifyOperatorUp(t))
@@ -684,7 +666,7 @@ func verifyDeletedImageStreamNotRecreated(t *testing.T) {
 }
 
 func verifyDeletedTemplatesRecreated(t *testing.T) {
-	err := templateClient.TemplateV1().Templates("openshift").Delete("jenkins-ephemeral", &metav1.DeleteOptions{})
+	err := templateClient.TemplateV1().Templates("openshift").Delete(context.TODO(), "jenkins-ephemeral", metav1.DeleteOptions{})
 	verifyConditionsCompleteSamplesAdded(t)
 	if err != nil {
 		dumpPod(t)
@@ -692,7 +674,7 @@ func verifyDeletedTemplatesRecreated(t *testing.T) {
 		t.Fatalf("error deleting jenkins imagestream %v samples resource %#v", err, cfg)
 	}
 	err = wait.PollImmediate(1*time.Second, 30*time.Second, func() (bool, error) {
-		_, err := templateClient.TemplateV1().Templates("openshift").Get("jenkins-ephemeral", metav1.GetOptions{})
+		_, err := templateClient.TemplateV1().Templates("openshift").Get(context.TODO(), "jenkins-ephemeral", metav1.GetOptions{})
 		if err == nil {
 			return true, nil
 		}
@@ -717,7 +699,7 @@ func verifyDeletedTemplatesNotRecreated(t *testing.T) {
 		return
 	}
 
-	err := templateClient.TemplateV1().Templates("openshift").Delete("jenkins-ephemeral", &metav1.DeleteOptions{})
+	err := templateClient.TemplateV1().Templates("openshift").Delete(context.TODO(), "jenkins-ephemeral", metav1.DeleteOptions{})
 	if err != nil {
 		dumpPod(t)
 		cfg := verifyOperatorUp(t)
@@ -726,7 +708,7 @@ func verifyDeletedTemplatesNotRecreated(t *testing.T) {
 	// make sure jenkins-ephemeral template does not appear while unmanaged
 	// first, wait sufficiently to make sure delete has gone though
 	err = wait.PollImmediate(1*time.Second, 10*time.Second, func() (bool, error) {
-		_, err := templateClient.TemplateV1().Templates("openshift").Get("jenkins-ephemeral", metav1.GetOptions{})
+		_, err := templateClient.TemplateV1().Templates("openshift").Get(context.TODO(), "jenkins-ephemeral", metav1.GetOptions{})
 		if kerrors.IsNotFound(err) {
 			return true, nil
 		}
@@ -739,7 +721,7 @@ func verifyDeletedTemplatesNotRecreated(t *testing.T) {
 	}
 	// now make sure it has not been recreated
 	time.Sleep(30 * time.Second)
-	_, err = templateClient.TemplateV1().Templates("openshift").Get("jenkins-ephemeral", metav1.GetOptions{})
+	_, err = templateClient.TemplateV1().Templates("openshift").Get(context.TODO(), "jenkins-ephemeral", metav1.GetOptions{})
 	if err == nil {
 		dumpPod(t)
 		cfg := verifyOperatorUp(t)
@@ -756,7 +738,6 @@ func TestImageStreamInOpenshiftNamespace(t *testing.T) {
 		dumpPod(t)
 		t.Fatalf("Config did not stabilize on startup %#v", verifyOperatorUp(t))
 	}
-	verifySecretPresent(t)
 	verifyClusterOperatorConditionsComplete(t, cfg.Status.Version, cfg.Status.ManagementState)
 	t.Logf("Config after TestImageStreamInOpenshiftNamespace: %#v", verifyOperatorUp(t))
 }
@@ -770,7 +751,7 @@ func TestRecreateConfigAfterDelete(t *testing.T) {
 
 		oldTime := cfg.CreationTimestamp
 
-		err := crClient.SamplesV1().Configs().Delete(samplesapi.ConfigName, &metav1.DeleteOptions{})
+		err := crClient.SamplesV1().Configs().Delete(context.TODO(), samplesapi.ConfigName, metav1.DeleteOptions{})
 		if err != nil {
 			dumpPod(t)
 			t.Fatalf("error deleting Config %v", err)
@@ -778,7 +759,7 @@ func TestRecreateConfigAfterDelete(t *testing.T) {
 
 		// make sure the cfg object is recreated vs. just finding the one we  tried to delete
 		err = wait.PollImmediate(1*time.Second, 10*time.Minute, func() (bool, error) {
-			cfg, err = crClient.SamplesV1().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+			cfg, err = crClient.SamplesV1().Configs().Get(context.TODO(), samplesapi.ConfigName, metav1.GetOptions{})
 			if err != nil {
 				return false, nil
 			}
@@ -813,7 +794,7 @@ func TestSpecManagementStateField(t *testing.T) {
 	err := retry.RetryOnConflict(retry.DefaultBackoff, func() error {
 		cfg := verifyOperatorUp(t)
 		cfg.Spec.ManagementState = operatorsv1api.Removed
-		cfg, err := crClient.SamplesV1().Configs().Update(cfg)
+		cfg, err := crClient.SamplesV1().Configs().Update(context.TODO(), cfg, metav1.UpdateOptions{})
 		return err
 	})
 	if err != nil {
@@ -821,7 +802,7 @@ func TestSpecManagementStateField(t *testing.T) {
 		t.Fatalf("error updating Config %v and %#v", err, verifyOperatorUp(t))
 	}
 	err = wait.PollImmediate(1*time.Second, 3*time.Minute, func() (bool, error) {
-		cfg, err = crClient.SamplesV1().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+		cfg, err = crClient.SamplesV1().Configs().Get(context.TODO(), samplesapi.ConfigName, metav1.GetOptions{})
 		if err != nil {
 			t.Logf("%v", err)
 			return false, nil
@@ -844,7 +825,7 @@ func TestSpecManagementStateField(t *testing.T) {
 	}
 
 	err = wait.PollImmediate(1*time.Second, 10*time.Minute, func() (bool, error) {
-		cfg, err = crClient.SamplesV1().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+		cfg, err = crClient.SamplesV1().Configs().Get(context.TODO(), samplesapi.ConfigName, metav1.GetOptions{})
 		if err != nil {
 			t.Logf("%v", err)
 			return false, nil
@@ -862,14 +843,13 @@ func TestSpecManagementStateField(t *testing.T) {
 
 	verifyImageStreamsGone(t)
 	verifyTemplatesGone(t)
-	verifySecretPresent(t)
 
 	verifyClusterOperatorConditionsComplete(t, cfg.Status.Version, cfg.Status.ManagementState)
 
 	err = retry.RetryOnConflict(retry.DefaultBackoff, func() error {
 		cfg = verifyOperatorUp(t)
 		cfg.Spec.ManagementState = operatorsv1api.Managed
-		cfg, err = crClient.SamplesV1().Configs().Update(cfg)
+		cfg, err = crClient.SamplesV1().Configs().Update(context.TODO(), cfg, metav1.UpdateOptions{})
 		return err
 	})
 	if err != nil {
@@ -877,7 +857,7 @@ func TestSpecManagementStateField(t *testing.T) {
 		t.Fatalf("error updating Config %v and %#v", err, cfg)
 	}
 	err = wait.PollImmediate(1*time.Second, 3*time.Minute, func() (bool, error) {
-		cfg, err = crClient.SamplesV1().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+		cfg, err = crClient.SamplesV1().Configs().Get(context.TODO(), samplesapi.ConfigName, metav1.GetOptions{})
 		if err != nil {
 			t.Logf("%v", err)
 			return false, nil
@@ -904,7 +884,7 @@ func TestSpecManagementStateField(t *testing.T) {
 	err = retry.RetryOnConflict(retry.DefaultBackoff, func() error {
 		cfg = verifyOperatorUp(t)
 		cfg.Spec.ManagementState = operatorsv1api.Unmanaged
-		cfg, err = crClient.SamplesV1().Configs().Update(cfg)
+		cfg, err = crClient.SamplesV1().Configs().Update(context.TODO(), cfg, metav1.UpdateOptions{})
 		return err
 	})
 	if err != nil {
@@ -912,7 +892,7 @@ func TestSpecManagementStateField(t *testing.T) {
 		t.Fatalf("error updating Config %v", err)
 	}
 	err = wait.PollImmediate(1*time.Second, 3*time.Minute, func() (bool, error) {
-		cfg, err = crClient.SamplesV1().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+		cfg, err = crClient.SamplesV1().Configs().Get(context.TODO(), samplesapi.ConfigName, metav1.GetOptions{})
 		if err != nil {
 			t.Logf("%v", err)
 			return false, nil
@@ -938,7 +918,7 @@ func TestSpecManagementStateField(t *testing.T) {
 		// and confirm all the default samples content exists
 		cfg = verifyOperatorUp(t)
 		cfg.Spec.ManagementState = operatorsv1api.Managed
-		cfg, err = crClient.SamplesV1().Configs().Update(cfg)
+		cfg, err = crClient.SamplesV1().Configs().Update(context.TODO(), cfg, metav1.UpdateOptions{})
 		return err
 	})
 	if err != nil {
@@ -946,7 +926,7 @@ func TestSpecManagementStateField(t *testing.T) {
 		t.Fatalf("error updating Config %v and %#v", err, cfg)
 	}
 	err = wait.PollImmediate(1*time.Second, 3*time.Minute, func() (bool, error) {
-		cfg, err = crClient.SamplesV1().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+		cfg, err = crClient.SamplesV1().Configs().Get(context.TODO(), samplesapi.ConfigName, metav1.GetOptions{})
 		if err != nil {
 			t.Logf("%v", err)
 			return false, nil
@@ -963,7 +943,7 @@ func TestSpecManagementStateField(t *testing.T) {
 
 	// wait for it to get into pending
 	err = wait.PollImmediate(1*time.Second, 3*time.Minute, func() (bool, error) {
-		cfg, err = crClient.SamplesV1().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+		cfg, err = crClient.SamplesV1().Configs().Get(context.TODO(), samplesapi.ConfigName, metav1.GetOptions{})
 		if err != nil {
 			t.Logf("%v", err)
 			return false, nil
@@ -1007,7 +987,7 @@ func TestSkippedProcessing(t *testing.T) {
 		cfg := verifyOperatorUp(t)
 		cfg.Spec.SkippedImagestreams = append(cfg.Spec.SkippedImagestreams, "jenkins")
 		cfg.Spec.SkippedTemplates = append(cfg.Spec.SkippedTemplates, "jenkins-ephemeral")
-		cfg, err := crClient.SamplesV1().Configs().Update(cfg)
+		cfg, err := crClient.SamplesV1().Configs().Update(context.TODO(), cfg, metav1.UpdateOptions{})
 		return err
 	})
 	if err != nil {
@@ -1037,7 +1017,7 @@ func TestSkippedProcessing(t *testing.T) {
 		cfg := verifyOperatorUp(t)
 		cfg.Spec.SkippedImagestreams = []string{}
 		cfg.Spec.SkippedTemplates = []string{}
-		cfg, err = crClient.SamplesV1().Configs().Update(cfg)
+		cfg, err = crClient.SamplesV1().Configs().Update(context.TODO(), cfg, metav1.UpdateOptions{})
 		return err
 	})
 	if err != nil {
@@ -1046,7 +1026,7 @@ func TestSkippedProcessing(t *testing.T) {
 	}
 	// verify status skipped has been reset
 	err = wait.PollImmediate(1*time.Second, 3*time.Minute, func() (bool, error) {
-		cfg, err := crClient.SamplesV1().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+		cfg, err := crClient.SamplesV1().Configs().Get(context.TODO(), samplesapi.ConfigName, metav1.GetOptions{})
 		if err != nil {
 			t.Logf("%v", err)
 			return false, nil
@@ -1115,7 +1095,7 @@ func coreTestUpgrade(t *testing.T) {
 	// update env to trigger upgrade
 	depClient := kubeClient.AppsV1().Deployments(samplesapi.OperatorNamespace)
 	err = wait.PollImmediate(1*time.Second, 3*time.Minute, func() (bool, error) {
-		dep, err := depClient.Get("cluster-samples-operator", metav1.GetOptions{})
+		dep, err := depClient.Get(context.TODO(), "cluster-samples-operator", metav1.GetOptions{})
 		if err != nil {
 			t.Logf("error waiting for operator deployment to exist: %v\n", err)
 			return false, nil
@@ -1126,7 +1106,7 @@ func coreTestUpgrade(t *testing.T) {
 			if strings.TrimSpace(env.Name) == "RELEASE_VERSION" {
 				t.Logf("updating RELEASE_VERSION env to %s", newVersion)
 				dep.Spec.Template.Spec.Containers[0].Env[i].Value = newVersion
-				_, err := depClient.Update(dep)
+				_, err := depClient.Update(context.TODO(), dep, metav1.UpdateOptions{})
 				if err == nil {
 					return true, nil
 				}
@@ -1183,7 +1163,7 @@ func changeMgmtState(t *testing.T, state operatorsv1api.ManagementState) {
 	err := retry.RetryOnConflict(retry.DefaultBackoff, func() error {
 		cfg := verifyOperatorUp(t)
 		cfg.Spec.ManagementState = state
-		cfg, err := crClient.SamplesV1().Configs().Update(cfg)
+		cfg, err := crClient.SamplesV1().Configs().Update(context.TODO(), cfg, metav1.UpdateOptions{})
 		return err
 	})
 	if err != nil {
@@ -1191,7 +1171,7 @@ func changeMgmtState(t *testing.T, state operatorsv1api.ManagementState) {
 		t.Fatalf("error updating Config %v and %#v", err, verifyOperatorUp(t))
 	}
 	err = wait.PollImmediate(1*time.Second, 3*time.Minute, func() (bool, error) {
-		cfg, err := crClient.SamplesV1().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+		cfg, err := crClient.SamplesV1().Configs().Get(context.TODO(), samplesapi.ConfigName, metav1.GetOptions{})
 		if err != nil {
 			t.Logf("%v", err)
 			return false, nil
